(* ::Package:: *)

(*:Package Version: 1.04 *)

(*:Version History: -.-- (2000.09.30 - 2008.09.14 : GammaRerated)
                    1.01 (2008.09.15 - 2009.12.19)
                    1.02 (2009.12.20 - 2012.12.12)
                    1.03 (2012.12.13 - 2015.01.09)
                    1.04 (2015.01.10 -     .  .  )GammaPrime *)

(*:Copyright: Copyright 2000.09-2015.01, Souichiro Ikebe *)

(*:Author: Souichiro Ikebe *)

(*:Name: SpecialFunctions`Gamma` *)

(*:Title: Gamma *)

(*:Keywords:
    HyperFactorial, GammaPrime, PearsonF *)

(*:Summary:
 
  This package implements some functions Rerated 
  Gamma functions.
*)

(*************************************************************************)





BeginPackage["SpecialFunctions`Gamma`"]





HyperFactorial::usage =
"HyperFactorial[z] gives the hyper factorial function."

GammaPrime::usage =
 "GammaPrime[d,z] gives the d-th derivative of gamma function.
 (0<=d<=9)."

PearsonF::usage =
"PearsonF[z,r] gives the Pearson's F-function."

MyPolyGamma::usage =
"MyPolyGamma[n,z] gives the poly-Gamma function used 
 Euler-Maclaurin calculus method."





Begin["SpecialFunctions`Gamma`Private`"]





Attributes[HyperFactorial]={Listable}

Attributes[GammaPrime]={Listable}

Attributes[PearsonF]={Listable}

Attributes[MyPolyGamma]={Listable}





(*************************************************************************)
(*                           HyperFactorial[z]                           *)
(*************************************************************************)

HyperFactorial[z_]:=
  Exp[z LogGamma[z+1]]/BarnesG[z+1]/;
  (Precision[z]<Infinity)

(*************************************************************************)
(*                            GammaPrime[d,z]                            *)
(*************************************************************************)

GammaPrime[0,z_]:=Gamma[z]/;
  (Precision[z]<Infinity)

GammaPrime[1,z_]:=Gamma[z]*PolyGamma[0,z]/;
  (Precision[z]<Infinity)

GammaPrime[2,z_]:=Gamma[z]*(PolyGamma[0,z]^2+PolyGamma[1,z])/;
  (Precision[z]<Infinity)

GammaPrime[3,z_]:=
  Module[{pg0},pg0=PolyGamma[0,z];
    Gamma[z]*(pg0^3+3*pg0*PolyGamma[1,z]+PolyGamma[2,z])]/;
  (Precision[z]<Infinity)

GammaPrime[4,z_]:=
  Module[{pg0,pg1},
    pg0=PolyGamma[0,z];pg1=PolyGamma[1,z];
    Gamma[z] (pg0^4+6*pg0^2*pg1+3*pg1^2+4*pg0*PolyGamma[2,z]+PolyGamma[3,z])]/;
  (Precision[z]<Infinity)

GammaPrime[5,z_]:=
  Module[{pg0,pg1,pg2},
    pg0=PolyGamma[0,z];pg1=PolyGamma[1,z];pg2=PolyGamma[2,z];
    Gamma[z]*(pg0^5+10*pg0^3*pg1+15*pg0*pg1^2+10*pg0^2*pg2+10*pg1*pg2+
      5*pg0*PolyGamma[3,z]+PolyGamma[4,z])]/;
  (Precision[z]<Infinity)

GammaPrime[6,z_]:=
  Module[{pg0,pg1,pg2,pg3},
    pg0=PolyGamma[0,z];pg1=PolyGamma[1,z];pg2=PolyGamma[2,z];
    pg3=PolyGamma[3,z];
    Gamma[z]*(pg0^6+15 pg0^4 pg1+45 pg0^2 pg1^2+15 pg1^3+20 pg0^3 pg2+
      60 pg0 pg1 pg2+10 pg2^2+15 pg0^2 pg3+15 pg1 pg3+
      6 pg0 PolyGamma[4,z]+PolyGamma[5,z])]/;
  (Precision[z]<Infinity)

GammaPrime[7,z_]:=
  Module[{pg0,pg1,pg2,pg3,pg4},
    pg0=PolyGamma[0,z];pg1=PolyGamma[1,z];pg2=PolyGamma[2,z];
    pg3=PolyGamma[3,z];pg4=PolyGamma[4,z];
    Gamma[z]*(pg0^7+21 pg0^5 pg1+105 pg0^3 pg1^2+105 pg0 pg1^3+35 pg0^4 pg2+
      210 pg0^2 pg1 pg2+105 pg1^2 pg2+70 pg0 pg2^2+35 pg0^3 pg3+
      105 pg0 pg1 pg3+35 pg2 pg3+21 pg0^2 pg4+21 pg1 pg4+
      7 pg0 PolyGamma[5,z]+PolyGamma[6,z])]/;
  (Precision[z]<Infinity)

GammaPrime[8,z_]:=
  Module[{pg0,pg1,pg2,pg3,pg4,pg5},
    pg0=PolyGamma[0,z];pg1=PolyGamma[1,z];pg2=PolyGamma[2,z];
    pg3=PolyGamma[3,z];pg4=PolyGamma[4,z];pg5=PolyGamma[5,z];
    Gamma[z]*(pg0^8+28 pg0^6 pg1+210 pg0^4 pg1^2+420 pg0^2 pg1^3+105 pg1^4+
      56 pg0^5 pg2+560 pg0^3 pg1 pg2+840 pg0 pg1^2 pg2+280 pg0^2 pg2^2+
      280 pg1 pg2^2+70 pg0^4 pg3+420 pg0^2 pg1 pg3+210 pg1^2 pg3+
      280 pg0 pg2 pg3+35 pg3^2+56 pg0^3 pg4+168 pg0 pg1 pg4+56 pg2 pg4+
      28 pg0^2 pg5+28 pg1 pg5+8 pg0 PolyGamma[6,z]+PolyGamma[7,z])]/;
  (Precision[z]<Infinity)

GammaPrime[9,z_]:=
  Module[{pg0,pg1,pg2,pg3,pg4,pg5,pg6},
    pg0=PolyGamma[0,z];pg1=PolyGamma[1,z];pg2=PolyGamma[2,z];
    pg3=PolyGamma[3,z];pg4=PolyGamma[4,z];pg5=PolyGamma[5,z];
    pg6=PolyGamma[6,z];
    Gamma[z]*(pg0^9+36 pg0^7 pg1+378 pg0^5 pg1^2+1260 pg0^3 pg1^3+
      945 pg0 pg1^4+84 pg0^6 pg2+1260 pg0^4 pg1 pg2+3780 pg0^2 pg1^2 pg2+
      1260 pg1^3 pg2+840 pg0^3 pg2^2+2520 pg0 pg1 pg2^2+280 pg2^3+
      126 pg0^5 pg3+1260 pg0^3 pg1 pg3+1890 pg0 pg1^2 pg3+
      1260 pg0^2 pg2 pg3+1260 pg1 pg2 pg3+315 pg0 pg3^2+
      126 pg0^4 pg4+756 pg0^2 pg1 pg4+378 pg1^2 pg4+504 pg0 pg2 pg4+
      126 pg3 pg4+84 pg0^3 pg5+252 pg0 pg1 pg5+84 pg2 pg5+36 pg0^2 pg6+
      36 pg1 pg6+9 pg0 PolyGamma[7,z]+PolyGamma[8,z])]/;
  (Precision[z]<Infinity)



(*************************************************************************)
(*                             PearsonF[z,r]                             *)
(*************************************************************************)

PearsonF[z_,r_]:=
  Pi/(2^z) Gamma[z+1]/Gamma[z/2+r I/2+1]/Gamma[z/2-r I/2+1]/;
  (Precision[z]<Infinity)



(*************************************************************************)
(*                           MyPolyGamma[n,z]                            *)
(*************************************************************************)

MyPolyGamma[z_]:=MyPolyGamma[0,z]/;
  (Precision[z]<Infinity)

MyPolyGamma[0,z_]:=
  Module[{summax=100},
  -EulerGamma-Sum[1/(z+k)-1/(k+1),{k,0,summax-1,1}]+
  Log[(z+summax)/(summax+1)]-(1/(z+summax)-1/(summax+1))/2-
  Sum[BernoulliB[2 j]/(2 j)*(1/(z+summax)^(2 j)-1/(summax+1)^(2 j)),{j,1,7}]]/;
  (Precision[z]<Infinity)

MyPolyGamma[1,z_]:=
  Module[{summax=100},
  Sum[1/(z+k)^2,{k,0,summax-1,1}]+1/(z+summax)+1/(2*(z+summax)^2)+
  Sum[BernoulliB[2 j]/((z+summax)^(2 j+1)),{j,1,7}]]/;
  (Precision[z]<Infinity)

MyPolyGamma[n_Integer,z_]:=
  Module[{summax=100},
  Sum[1/(z+k)^(n+1),{k,0,summax-1,1}]+
  1/(n*(z+summax)^n)+1/(2*(z+summax)^(n+1))+
  Sum[BernoulliB[2 j]/(n!)*
  Product[2 j+i,{i,1,n-1,1}]/((z+summax)^(n+2 j)),{j,1,7}]]*n!*(-1)^(n+1)/;
  (Precision[z]<Infinity)



(*************************************************************************)

End[]

Protect[HyperFactorial, GammaPrime, PearsonF, MyPolyGamma]

EndPackage[]
